/**
 * Copyright (c) Jonathan Cardoso Machado. All Rights Reserved.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { CurlOptionValueType } from './generated/CurlOption';
import { HeaderInfo } from './parseHeaders';
export interface CurlxPromise {
    data: string;
    headers: HeaderInfo[];
    statusCode: number;
}
declare const methods: readonly ["acl", "bind", "checkout", "connect", "copy", "delete", "get", "head", "link", "lock", "m-search", "merge", "mkactivity", "mkcalendar", "mkcol", "move", "notify", "options", "patch", "post", "propfind", "proppatch", "purge", "put", "rebind", "report", "search", "source", "subscribe", "trace", "unbind", "unlink", "unlock", "unsubscribe"];
declare type HttpMethod = (typeof methods)[number];
interface CurlxHttpMethodCall {
    /**
     * **EXPERIMENTAL** This API can change between minor releases
     *
     * Async wrapper around the Curl class.
     *
     * The `curl.<field>` being used will be the HTTP verb sent.
     */
    (url: string, options?: CurlOptionValueType): Promise<CurlxPromise>;
}
declare type HttpMethodCalls = {
    [K in HttpMethod]: CurlxHttpMethodCall;
};
export interface Curlx extends HttpMethodCalls {
    /**
     * Async wrapper around the Curl class
     * It's also possible to request using a specific http verb
     *  directly by using `curl.<http-verb>(url)`
     */
    (url: string, options?: CurlOptionValueType): Promise<CurlxPromise>;
    create: () => Curlx;
}
/**
 * Async wrapper around the {@link Curl | Curl class}
 *
 * @remarks
 * It's also possible to request using a specific http verb
 *  directly by using `curl.<http-verb>(url)`
 *
 * @example
 * ```
 *
 * ```
 *
 * @param url - URL the request should be submitted to
 * @param options - options
 *
 * @beta
 */
export declare const curlx: Curlx;
export {};
//# sourceMappingURL=curlx.d.ts.map