import { CurlShareOption } from './enum/CurlShareOption'
import { CurlShareCode } from './enum/CurlCode'
import { CurlShareLock } from './enum/CurlShareLock'

/**
 * Copyright (c) Jonathan Cardoso Machado. All Rights Reserved.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

/**
 * Share class
 *
 * @public
 */
declare class Share {
  /**
   * Options to be used with `Share.setOpt`
   *
   * See the official documentation of [curl_share_setopt()](http://curl.haxx.se/libcurl/c/curl_share_setopt.html)
   *  for reference.
   *
   * `CURLSHOPT_SHARE` becomes `Share.option.SHARE`
   */
  static option: CurlShareOption

  /**
   * Returns a description for the given error code.
   *
   * Official libcurl documentation: [curl_share_strerror()](http://curl.haxx.se/libcurl/c/curl_share_strerror.html)
   */
  static strError(errorCode: CurlShareCode): string

  /**
   * Use `Curl.share` and `Curl.lock` for predefined constants.
   *
   * Official libcurl documentation: [curl_share_setopt()](http://curl.haxx.se/libcurl/c/curl_share_setopt.html)
   */
  setOpt(option: CurlShareOption, value: CurlShareLock): CurlShareCode

  /**
   * Closes this share handle.
   *
   * This is basically the same than [curl_share_cleanup()](http://curl.haxx.se/libcurl/c/curl_share_cleanup.html)
   */
  close(): void
}

export { Share }
